@@ -106,6 +106,12 @@ void account_on( irc_t *irc, account_t *a )
 		return;
 	}
 	
+	if( proto_prpl[a->protocol] == NULL )
+	{
+		irc_usermsg( irc, "Support for protocol %s is not included in this BitlBee", proto_name[a->protocol] );
+		return;
+	}
+	
 	cancel_auto_reconnect( a );
 	
 	u = malloc( sizeof( struct aim_user ) );
